@@ -29,6 +29,8 @@ def helm3_install(dependency, default_values_path):
         else ""
     )
     command = "upgrade" if release_exists(dependency) else "install"
+    wait = "--wait" if dependency.get("wait", True) else ""
+    args = dependency.get("args", "")
     with tempfile.NamedTemporaryFile(suffix=".tmp", delete=False) as override_yaml:
         override_yaml.write(
             yaml.dump(dependency.get("values", {}), default_flow_style=False).encode(
@@ -39,7 +41,7 @@ def helm3_install(dependency, default_values_path):
         run_cmd(f"helm3 repo add {repo_name} {dependency['repository']}")
         run_cmd("helm3 repo update", silent=True)
         run_cmd(
-            f"helm3 {command} {namespace} {dependency['name']} {repo_name}/{dependency['name']} --create-namespace {default_values} -f {override_yaml.name} --version {dependency['version']}"
+            f"helm3 {command} {namespace} {wait} {args} {dependency['name']} {repo_name}/{dependency['name']} --create-namespace {default_values} -f {override_yaml.name} --version {dependency['version']}"
         )
 
 
